@@ -1,7 +1,7 @@
 from Testing import ZopeTestCase as ztc
 from Products.PloneTestCase import PloneTestCase as ptc
 from Products.PloneTestCase.layer import onsetup
-from Products.Five import zcml
+# from Products.Five import zcml
 from Products.Five import fiveconfigure
 
 import ilrt.migrationtool
@@ -9,8 +9,6 @@ import ilrt.migrationtool
 @onsetup
 def setup_products():
     fiveconfigure.debug_mode = True
-    zcml.load_config('configure.zcml',
-                     ilrt.formalworkflow)
     fiveconfigure.debug_mode = False    
     ztc.installPackage('ilrt.migrationtool')
 
